@@ -26,14 +26,7 @@ void FileSystemImageFetcher::fetch()
 
 void FileSystemImageFetcher::slotProcess()
 {
-    static QMimeDatabase mimeDb;
-
-    static constexpr auto allowedExtensions = std::to_array<QLatin1StringView>({
-        "png"_L1,
-        "jpg"_L1,
-        "jpeg"_L1,
-        "heic"_L1,
-    });
+    QMimeDatabase db;
 
     QDirIterator it(m_folder, QDirIterator::Subdirectories);
     while (it.hasNext()) {
@@ -44,21 +37,10 @@ void FileSystemImageFetcher::slotProcess()
             continue;
         }
 
-        const auto extension = QStringView(filePath).split('.').constLast();
-        if (std::ranges::find_if(allowedExtensions,
-                                 [&extension](const QLatin1StringView &allowedExtension) -> bool {
-                                     return allowedExtension == extension;
-                                 })
-            != allowedExtensions.cend()) {
+        const auto mimetype = db.mimeTypeForFile(filePath, QMimeDatabase::MatchMode::MatchExtension).name();
+        if (mimetype.startsWith("image/"_L1) || mimetype.startsWith("video/"_L1)) {
             Q_EMIT imageResult(filePath);
-            return;
         }
-
-        const QString mimetype = mimeDb.mimeTypeForFile(filePath).name();
-        if (!mimetype.startsWith("image/"_L1) && !mimetype.startsWith("video/"_L1))
-            continue;
-
-        Q_EMIT imageResult(filePath);
     }
 
     Q_EMIT finished();
